pub fn should_inject_memory(
graph: &PheromoneGraph,
runs_since_last_inject: u32,
min_runs_between_inject: u32,
) -> boolExpand description
Whether enough runs have passed to inject memory into the prompt.
pub fn should_inject_memory(
graph: &PheromoneGraph,
runs_since_last_inject: u32,
min_runs_between_inject: u32,
) -> boolWhether enough runs have passed to inject memory into the prompt.